@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Data::Dumper;
 use Data::Uniqid;
-use RDF::Helper::RDFRedland::TiedPropertyHash;
+use RDF::Helper::TiedPropertyHash;
 use vars qw( $AUTOLOAD );
 use overload
     '""' => \&object_uri,
@@ -15,15 +15,15 @@ use overload
 
 =head1 NAME
 
-RDF::Helper::Object - Perl extension for blah blah blah
+RDF::Helper::Object - Perl extension to use RDF property names as methods
 
 =head1 SYNOPSIS
 
   use RDF::Helper;
   my $rdf = RDF::Helper->new(
-      BaseInterface => 'RDF::Redland',
+      BaseInterface => 'RDF::Trine',
       Namespaces => { 
-        dc => 'http://purl.org/dc/elements/1.1/',
+        dc => 'http://purl.org/dc/terms/',
         rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
         '#default' => "http://purl.org/rss/1.0/"
      }
@@ -54,7 +54,7 @@ sub new {
 
     $self->{_uri_} = $args{ResourceURI} || "urn:" . Data::Uniqid::uniqid;
     $self->{_rdftype_} = $args{RDFType};
-    $self->{_defaultns_} = $args{DefaultNS} || $self->{_datastore_}->{Namespaces}->{'#default'};
+    $self->{_defaultns_} = $args{DefaultNS} || $self->{_datastore_}->namespaces->{'#default'} || '';
         
     if ( defined( $args{NoTie} ) and $args{NoTie} == 1 ) {
         $self->{_data_} = $self->{_datastore_}->property_hash(
@@ -171,8 +171,8 @@ sub AUTOLOAD {
     if ($attr =~ /^([^_]+)_(.+)$/) {
         my $nsprefix = $1;
         my $nsattr = $2;
-        if ($self->{_datastore_}->{Namespaces}->{$nsprefix}) {
-            $ns = $self->{_datastore_}->{Namespaces}->{$nsprefix};
+        if ($self->{_datastore_}->namespaces->{$nsprefix}) {
+            $ns = $self->{_datastore_}->namespaces->{$nsprefix};
             $attr = $nsprefix . ':' . $nsattr;
             $attr_uri = $ns . $nsattr;
         }
